@@ -23,17 +23,20 @@ pub mod raw_message;
 pub mod stage;
 
 mod builder;
+mod command;
 mod config;
 mod emitter;
 mod event;
 mod r#impl;
 mod json;
 mod processor;
+pub(crate) mod tls;
 
 pub use self::{
     builder::{
         LargeThresholdError, LargeThresholdErrorType, ShardBuilder, ShardIdError, ShardIdErrorType,
     },
+    command::Command,
     config::Config,
     event::Events,
     processor::heartbeat::Latency,
